==> org.eclipse.pde.junit.runtime.source_3.6.0.v20210513-1344.jar: org/eclipse/pde/internal/junit/runtime/MultiBundleClassLoader.java <==
/*******************************************************************************
 *  Copyright (c) 2018 IBM Corporation and others.
 *
 *  This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License 2.0
 *  which accompanies this distribution, and is available at
 *  https://www.eclipse.org/legal/epl-2.0/
 *
 *  SPDX-License-Identifier: EPL-2.0
 *
 *  Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.internal.junit.runtime;

import java.io.IOException;
import java.net.URL;
import java.util.*;
import org.osgi.framework.Bundle;

class MultiBundleClassLoader extends ClassLoader {
	private List<Bundle> bundleList;

	public MultiBundleClassLoader(List<Bundle> platformEngineBundles) {
		this.bundleList = platformEngineBundles;

	}

	@Override
	protected Class<?> findClass(String name) throws ClassNotFoundException {
		for (Bundle temp : bundleList) {
			try {
				Class<?> c = temp.loadClass(name);
				if (c != null)
					return c;
			} catch (ClassNotFoundException e) {
			}
		}
		throw new ClassNotFoundException(name);
	}

	@Override
	protected URL findResource(String name) {
		URL url = null;
		for (Bundle temp : bundleList) {
			url = temp.getResource(name);
			if (url != null)
				return url;
		}
		return url;
	}

	@Override
	protected Enumeration<URL> findResources(String name) throws IOException {
		Enumeration<URL> enumFinal = null;
		for (int i = 0; i < bundleList.size(); i++) {
			if (i == 0) {
				enumFinal = bundleList.get(i).getResources(name);
				continue;
			}
			Enumeration<URL> e2 = bundleList.get(i).getResources(name);
			Vector<URL> temp = new Vector<>();
			while (enumFinal != null && enumFinal.hasMoreElements()) {
				temp.add(enumFinal.nextElement());
			}
			while (e2 != null && e2.hasMoreElements()) {
				temp.add(e2.nextElement());
			}
			enumFinal = temp.elements();
		}
		return enumFinal;
	}
}

==> org.eclipse.pde.junit.runtime.source_3.6.200.v20220523-1051.jar: org/eclipse/pde/internal/junit/runtime/MultiBundleClassLoader.java <==
/*******************************************************************************
 *  Copyright (c) 2018 IBM Corporation and others.
 *
 *  This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License 2.0
 *  which accompanies this distribution, and is available at
 *  https://www.eclipse.org/legal/epl-2.0/
 *
 *  SPDX-License-Identifier: EPL-2.0
 *
 *  Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.internal.junit.runtime;

import java.io.IOException;
import java.net.URL;
import java.util.*;
import org.eclipse.core.runtime.FileLocator;
import org.osgi.framework.Bundle;

class MultiBundleClassLoader extends ClassLoader {
	private List<Bundle> bundleList;

	public MultiBundleClassLoader(List<Bundle> platformEngineBundles) {
		super(null); // never delegate to system classloader, only load classes via given Bundles
		this.bundleList = platformEngineBundles;
	}

	@Override
	protected Class<?> findClass(String name) throws ClassNotFoundException {
		for (Bundle temp : bundleList) {
			try {
				Class<?> c = temp.loadClass(name);
				if (c != null)
					return c;
			} catch (ClassNotFoundException e) {
			}
		}
		throw new ClassNotFoundException(name);
	}

	@Override
	protected URL findResource(String name) {
		URL url = null;
		for (Bundle temp : bundleList) {
			url = temp.getResource(name);
			if (url != null) {
				try {
					return FileLocator.resolve(url);
				} catch (IOException e) {
					return null;
				}
			}
		}
		return url;
	}

	@Override
	protected Enumeration<URL> findResources(String name) throws IOException {
		List<URL> merged = new ArrayList<>();
		for (Bundle bundle : bundleList) {
			Enumeration<URL> resources = bundle.getResources(name);
			while (resources != null && resources.hasMoreElements()) {
				merged.add(FileLocator.resolve(resources.nextElement()));
			}
		}
		return Collections.enumeration(merged);
	}
}
